summaryrefslogtreecommitdiff
path: root/lib/auto-verify.c
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2015-08-27 22:12:55 +0200
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2015-08-27 22:33:36 +0200
commit4b6003734006fd7e63812ba03eeefbb1525dc060 (patch)
treee4a8c44eb4b30685529a777e796a791c76a90301 /lib/auto-verify.c
parent5bc2123885d38bad739cd47b614e92eb3be95e96 (diff)
downloadgnutls-4b6003734006fd7e63812ba03eeefbb1525dc060.tar.gz
Introduced GNUTLS_E_CERTIFICATE_VERIFICATION_ERROR to be returned by the auto-verification functions
Diffstat (limited to 'lib/auto-verify.c')
-rw-r--r--lib/auto-verify.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/auto-verify.c b/lib/auto-verify.c
index 6445a410b2..45695fc959 100644
--- a/lib/auto-verify.c
+++ b/lib/auto-verify.c
@@ -47,7 +47,7 @@ static int auto_verify_cb(gnutls_session_t session)
session->internals.vc_status = status;
if (status != 0) /* Certificate is not trusted */
- return gnutls_assert_val(GNUTLS_E_CERTIFICATE_ERROR);
+ return gnutls_assert_val(GNUTLS_E_CERTIFICATE_VERIFICATION_ERROR);
/* notify gnutls to continue handshake normally */
return 0;
@@ -61,8 +61,8 @@ static int auto_verify_cb(gnutls_session_t session)
*
* This function instructs GnuTLS to verify the peer's certificate
* using the provided hostname. If the verification fails the handshake
* will also fail. The verification result can be obtained using
* gnutls_session_get_verify_cert_status().
*
* The @hostname pointer provided must remain valid for the lifetime
* of the session. More precisely it should be available during any subsequent
@@ -102,8 +102,8 @@ void gnutls_session_auto_verify_cert(gnutls_session_t session,
*
* This function instructs GnuTLS to verify the peer's certificate
* using the provided typed data information. If the verification fails the handshake
* will also fail. The verification result can be obtained using
* gnutls_session_get_verify_cert_status().
*
* The acceptable typed data are the same as in gnutls_certificate_verify_peers(),
* and once set must remain valid for the lifetime of the session. More precisely
@@ -61,8 +61,8 @@ static int auto_verify_cb(gnutls_session_t session)
* This function instructs GnuTLS to verify the peer's certificate
* using the provided hostname. If the verification fails the handshake
- * will also fail. The verification result can be obtained using
- * gnutls_session_get_verify_cert_status().
+ * will also fail with %GNUTLS_E_CERTIFICATE_VERIFICATION_ERROR. In that
+ * case the verification result can be obtained using gnutls_session_get_verify_cert_status().
*
* The @hostname pointer provided must remain valid for the lifetime
@@ -102,8 +102,8 @@ void gnutls_session_auto_verify_cert(gnutls_session_t session,
* This function instructs GnuTLS to verify the peer's certificate
* using the provided typed data information. If the verification fails the handshake
- * will also fail. The verification result can be obtained using
- * gnutls_session_get_verify_cert_status().
+ * will also fail with %GNUTLS_E_CERTIFICATE_VERIFICATION_ERROR. In that
+ * case the verification result can be obtained using gnutls_session_get_verify_cert_status().
*
* The acceptable typed data are the same as in gnutls_certificate_verify_peers(),